/* tslint:disable */
/* eslint-disable */
/**
* See [`FindexSearch::search()`](cosmian_findex::FindexSearch::search).
*
* # Parameters
*
* - `master_key`              : master key
* - `label_bytes`             : bytes of the public label used for hashing
* - `keywords`                : list of keyword bytes to search
* - `progress`                : progress callback
* - `fetch_entries`           : callback to fetch from the Entry Table
* - `fetch_chains`            : callback to fetch from the Chain Table
* @param {Uint8Array} master_key
* @param {Uint8Array} label_bytes
* @param {Array<Uint8Array>} keywords
* @param {(progressResults: Array<{ keyword: Uint8Array, results: Array<Uint8Array> }>) => Promise<Boolean>} progress
* @param {(uids: Uint8Array[]) => Promise<{uid: Uint8Array, value: Uint8Array}[]>} fetch_entry
* @param {(uids: Uint8Array[]) => Promise<{uid: Uint8Array, value: Uint8Array}[]>} fetch_chain
* @returns {Promise<Array<{ keyword: Uint8Array, results: Array<Uint8Array> }>>}
*/
export function webassembly_search(master_key: Uint8Array, label_bytes: Uint8Array, keywords: Array<Uint8Array>, progress: (progressResults: Array<{ keyword: Uint8Array, results: Array<Uint8Array> }>) => Promise<Boolean>, fetch_entry: (uids: Uint8Array[]) => Promise<{uid: Uint8Array, value: Uint8Array}[]>, fetch_chain: (uids: Uint8Array[]) => Promise<{uid: Uint8Array, value: Uint8Array}[]>): Promise<Array<{ keyword: Uint8Array, results: Array<Uint8Array> }>>;
/**
* @returns {Promise<void>}
*/
export function webassembly_logger_init(): Promise<void>;
/**
* See [`FindexUpsert::upsert()`](cosmian_findex::FindexUpsert::upsert).
*
* # Parameters
*
* - `master_key`                  : master key
* - `label_bytes`                 : public label used for hashing
* - `indexed_value_to_keywords`   : map of `IndexedValue`s to `Keyword` bytes
* - `fetch_entries`               : the callback to fetch from the entry table
* - `upsert_entries`              : the callback to upsert in the entry table
* - `insert_chains`               : the callback to insert in the chain table
*
* # Returns
* The list of new keywords added to the entry table.
* @param {Uint8Array} master_key
* @param {Uint8Array} label_bytes
* @param {Array<{indexedValue: Uint8Array, keywords: Uint8Array[]}>} additions
* @param {Array<{indexedValue: Uint8Array, keywords: Uint8Array[]}>} deletions
* @param {(uids: Uint8Array[]) => Promise<{uid: Uint8Array, value: Uint8Array}[]>} fetch_entry
* @param {(uidsAndValues: {uid: Uint8Array, oldValue: Uint8Array | null, newValue: Uint8Array}[]) => Promise<{uid: Uint8Array, value: Uint8Array}[]>} upsert_entry
* @param {(uidsAndValues: {uid: Uint8Array, value: Uint8Array}[]) => Promise<void>} insert_chain
* @returns {Promise<Array<Uint8Array>>}
*/
export function webassembly_upsert(master_key: Uint8Array, label_bytes: Uint8Array, additions: Array<{indexedValue: Uint8Array, keywords: Uint8Array[]}>, deletions: Array<{indexedValue: Uint8Array, keywords: Uint8Array[]}>, fetch_entry: (uids: Uint8Array[]) => Promise<{uid: Uint8Array, value: Uint8Array}[]>, upsert_entry: (uidsAndValues: {uid: Uint8Array, oldValue: Uint8Array | null, newValue: Uint8Array}[]) => Promise<{uid: Uint8Array, value: Uint8Array}[]>, insert_chain: (uidsAndValues: {uid: Uint8Array, value: Uint8Array}[]) => Promise<void>): Promise<Array<Uint8Array>>;
/**
* See [`FindexSearch::search()`](cosmian_findex::FindexSearch::search).
*
* # Parameters
*
* - `master_key`              : master key
* - `label_bytes`             : bytes of the public label used for hashing
* - `keywords`                : list of keyword bytes to search
* - `base_url`                : base URL for Findex Cloud (with http prefix
*   and port if required). If null, use the default Findex Cloud server.
* @param {string} token
* @param {Uint8Array} label_bytes
* @param {Array<Uint8Array>} keywords
* @param {string | undefined} [base_url]
* @returns {Promise<Array<{ keyword: Uint8Array, results: Array<Uint8Array> }>>}
*/
export function webassembly_search_cloud(token: string, label_bytes: Uint8Array, keywords: Array<Uint8Array>, base_url?: string): Promise<Array<{ keyword: Uint8Array, results: Array<Uint8Array> }>>;
/**
* See [`FindexUpsert::upsert()`](cosmian_findex::FindexUpsert::upsert).
*
* # Parameters
*
* - `token`                       : findex cloud token
* - `label_bytes`                 : public label used for hashing
* - `indexed_value_to_keywords`   : map of `IndexedValue`s to `Keyword` bytes
* - `base_url`                : base URL for Findex Cloud (with http prefix
*   and port if required). If null, use the default Findex Cloud server.
* @param {string} token
* @param {Uint8Array} label_bytes
* @param {Array<{indexedValue: Uint8Array, keywords: Uint8Array[]}>} additions
* @param {Array<{indexedValue: Uint8Array, keywords: Uint8Array[]}>} deletions
* @param {string | undefined} [base_url]
* @returns {Promise<Array<Uint8Array>>}
*/
export function webassembly_upsert_cloud(token: string, label_bytes: Uint8Array, additions: Array<{indexedValue: Uint8Array, keywords: Uint8Array[]}>, deletions: Array<{indexedValue: Uint8Array, keywords: Uint8Array[]}>, base_url?: string): Promise<Array<Uint8Array>>;
/**
* Generate a new Findex Cloud token with reduced permissions
* @param {string} token
* @param {boolean} search
* @param {boolean} index
* @returns {string}
*/
export function webassembly_derive_new_token(token: string, search: boolean, index: boolean): string;
/**
* Generate a new random Findex Cloud token
* @param {string} index_id
* @param {Uint8Array} fetch_entries_seed
* @param {Uint8Array} fetch_chains_seed
* @param {Uint8Array} upsert_entries_seed
* @param {Uint8Array} insert_chains_seed
* @returns {string}
*/
export function webassembly_generate_new_token(index_id: string, fetch_entries_seed: Uint8Array, fetch_chains_seed: Uint8Array, upsert_entries_seed: Uint8Array, insert_chains_seed: Uint8Array): string;

export type InitInput = RequestInfo | URL | Response | BufferSource | WebAssembly.Module;

export interface InitOutput {
  readonly memory: WebAssembly.Memory;
  readonly webassembly_search: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly webassembly_logger_init: () => number;
  readonly webassembly_upsert: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly webassembly_search_cloud: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly webassembly_upsert_cloud: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly webassembly_derive_new_token: (a: number, b: number, c: number, d: number, e: number) => void;
  readonly webassembly_generate_new_token: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => void;
  readonly __wbindgen_export_0: (a: number, b: number) => number;
  readonly __wbindgen_export_1: (a: number, b: number, c: number, d: number) => number;
  readonly __wbindgen_export_2: WebAssembly.Table;
  readonly __wbindgen_export_3: (a: number, b: number, c: number) => void;
  readonly __wbindgen_add_to_stack_pointer: (a: number) => number;
  readonly __wbindgen_export_4: (a: number, b: number, c: number) => void;
  readonly __wbindgen_export_5: (a: number) => void;
  readonly __wbindgen_export_6: (a: number, b: number, c: number, d: number) => void;
}

export type SyncInitInput = BufferSource | WebAssembly.Module;
/**
* Instantiates the given `module`, which can either be bytes or
* a precompiled `WebAssembly.Module`.
*
* @param {SyncInitInput} module
*
* @returns {InitOutput}
*/
export function initSync(module: SyncInitInput): InitOutput;

/**
* If `module_or_path` is {RequestInfo} or {URL}, makes a request and
* for everything else, calls `WebAssembly.instantiate` directly.
*
* @param {InitInput | Promise<InitInput>} module_or_path
*
* @returns {Promise<InitOutput>}
*/
export default function __wbg_init (module_or_path?: InitInput | Promise<InitInput>): Promise<InitOutput>;
